﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:decimal-format name="bg" decimal-separator="." grouping-separator="," NaN="(няма)" />
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>Потребителски кредит</title>
				<meta http-equiv="Content-Type" content="text/html; charset=utf8" />
				<style type="text/css">
					<![CDATA[
          body, td, th
          {
          margin: 0px;
          font-family: Trebuchet MS, Arial, Sans-Serif;
          font-size: 9pt;
          color: #000000;
          }
          th
          {
          text-align: left;
          border: 1px solid #999999;
          font-weight: bold;
          }
          ]]>
				</style>
			</head>
			<body>
				<table style="width: 100%">
					<tr>
						<th colspan="4">
							Потребителски кредит
						</th>
					</tr>
					<tr>
						<th colspan="4">
							Параметри на кредита
						</th>
					</tr>
					<tr>
						<td style="text-align: right">
							Размер на кредита:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/amount), '###,##0.00', 'bg')"  />
							вал. ед.
						</td>
						<td style="text-align: right">
							Срок на кредита:
						</td>
						<td>
							<xsl:value-of select="number(loan/parameters/period)"  />
							месец(а)
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Лихвен процент:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/interest), '###,##0.00', 'bg')" />
							%
						</td>
						<td style="text-align: right">
							Дата на усвояване:
						</td>
						<td>
							<xsl:value-of select="substring-before(loan/parameters/aquisition-date,'T')" />
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Гратисен период:
						</td>
						<td>
							<xsl:choose>
								<xsl:when test="number(loan/parameters/grace-period) &gt; 0">
									<xsl:value-of select="number(loan/parameters/grace-period)"/>
									месец(а)
								</xsl:when>
								<xsl:otherwise>
									Няма
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td style="text-align: right">
							Капитализация на лихвата:
						</td>
						<td>
							<xsl:choose>
								<xsl:when test="number(loan/parameters/grace-period-capitalisation) &gt; 0">
									Да
								</xsl:when>
								<xsl:otherwise>
									Не
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Начин на погасяване:
						</td>
						<td>
							<xsl:if test="loan/parameters/repayment-method = 'annuity-repayments'">
								анюитетни вноски
							</xsl:if>
							<xsl:if test="loan/parameters/repayment-method = 'equal-payments-on-principal'">
								равни вноски по главница
							</xsl:if>
						</td>
						<td style="text-align: right">
							Лихвена база:
						</td>
						<td>
							<xsl:value-of select="loan/parameters/interest-base" />
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Промоционална лихва:
						</td>
						<td>
							<xsl:choose>
								<xsl:when test="number(loan/parameters/promotion-interest) &gt; 0">
									<xsl:value-of select="format-number(number(loan/parameters/promotion-interest), '###,##0.00', 'bg')"/>
									%
								</xsl:when>
								<xsl:otherwise>
									Няма
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td style="text-align: right">
							Промоционален период:
						</td>
						<td>
							<xsl:choose>
								<xsl:when test="number(loan/parameters/promotion-period) &gt; 0">
									<xsl:value-of select="number(loan/parameters/promotion-period)"/>
									месец(а)
								</xsl:when>
								<xsl:otherwise>
									Няма
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Такса обработка:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/processing-fee), '###,##0.00', 'bg')"/>
							вал. ед.
						</td>
						<td style="text-align: right">
							Първоначална такса управление:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/management-fee-perc), '###,##0.00', 'bg')"/>
							вал. ед.
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Застрахователна сума:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/insurance-amount), '###,##0.00', 'bg')"/>
							%
						</td>
						<td style="text-align: right">
							Месечна такса управление:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/monthly-management-fee), '###,##0.00', 'bg')"/>
							%
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Застрахователни разходи:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/insurance-expenses), '###,##0.00', 'bg')"/>
							%
						</td>
						<td style="text-align: right">
							Ежегодна такса управление:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/annual-management-fee), '###,##0.00', 'bg')"/>
							%
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Други първоначални разходи:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/other-expenses), '###,##0.00', 'bg')"/>
							вал. ед.
						</td>
						<td style="text-align: right">
							Други първоначални разходи:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/other-expenses-perc), '###,##0.00', 'bg')"/>
							%
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Други месечни разходи:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/other-monthly-expenses), '###,##0.00', 'bg')"/>
							%
						</td>
						<td style="text-align: right">
							Други ежегодни разходи:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/other-annual-expenses), '###,##0.00', 'bg')"/>
							%
						</td>
					</tr>
					<tr>
						<th colspan="4">
							Резултати от изчисленията
						</th>
					</tr>
					<tr>
						<td style="text-align: right">
							Размер на кредита:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/parameters/amount), '###,##0.00', 'bg')"  />
							вал. ед.
						</td>
						<td style="text-align: right">
							Общо плащания:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/result/total-payments), '###,##0.00', 'bg')"/>
							вал. ед.
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Общо лихви:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/result/total-interests), '###,##0.00', 'bg')"/>
							вал. ед.
						</td>
						<td style="text-align: right">
							Общо такси:
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/result/total-taxes), '###,##0.00', 'bg')"/>
							вал. ед.
						</td>
					</tr>
					<tr>
						<td style="text-align: right">
							Годишен процент на разхода (ГПР):
						</td>
						<td>
							<xsl:value-of select="format-number(number(loan/result/ycr), '###,##0.00', 'bg')"/>
							%
						</td>
					</tr>
					<tr>
						<th colspan="4">
							Погасителен план
						</th>
					</tr>
					<tr>
						<td colspan="4">
							<table style="width: 100%">
								<tr>
									<th>
										Период
									</th>
									<th>
										Остатък
									</th>
									<th>
										Лихва
									</th>
									<th>
										Вноска по главницата
									</th>
									<th>
										Вноска за периода
									</th>
									<th>
										Такси и комисионни
									</th>
									<th>
										Общо
									</th>
								</tr>
								<xsl:for-each select="loan/result/repayments/repayment">
									<tr>
										<td style="text-align: right">
											<xsl:value-of select="number(period)" />
										</td>
										<td style="text-align: right">
											<xsl:value-of select="format-number(number(balance), '###,##0.00', 'bg')" />
										</td>
										<td style="text-align: right">
											<xsl:value-of select="format-number(number(interest), '###,##0.00', 'bg')" />
										</td>
										<td style="text-align: right">
											<xsl:value-of select="format-number(number(principal-repayment), '###,##0.00', 'bg')" />
										</td>
										<td style="text-align: right">
											<xsl:value-of select="format-number(number(repayment), '###,##0.00', 'bg')" />
										</td>
										<td style="text-align: right">
											<xsl:value-of select="format-number(number(taxes), '###,##0.00', 'bg')" />
										</td>
										<td style="text-align: right">
											<xsl:value-of select="format-number(number(total), '###,##0.00', 'bg')" />
										</td>
									</tr>
								</xsl:for-each>
							</table>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
