﻿using System;
using System.IO;
using System.Text;
using System.Xml.Serialization;
using System.Xml;

namespace XmlSerialization
{
	internal class Program
	{
		private static void DemoSerialization(string fileName)
		{
			#region Създава списък от Person

			Person[] persons = new[]
			{
				new Person
				{
					Identifier = "8210081121",
					FirstName = "Valery",
					MiddleName = "Petrov",
					LastName = "Dachev",
					Birthday = new DateTime(1982, 10, 8),
					Gender = Gender.Male,
				},
				new Person
				{
					Identifier = "3012081111",
					FirstName = "Stanka",
					MiddleName = "Pencheva",
					LastName = "Ivanova",
					Birthday = new DateTime(1930, 12, 8),
					Gender = Gender.Female,
				},
			};

			#endregion

			// отваря файла за писане като поток
			using (var stream = new FileStream(fileName, FileMode.Open, FileAccess.Write))
			{
				// искаме да сериализираме масив от Person
				var serializer = new XmlSerializer(typeof(Person[]));
				// сериализираме подадения масив в поток
				serializer.Serialize(stream, persons);
			}
		}

		private static void DemoDeserialization(string fileName)
		{
			// отваряме файла за четене като поток
			using (var stream = new FileStream(fileName, FileMode.Open, FileAccess.Read))
			{
				// искаме да десериализираме масив от Person
				var serializer = new XmlSerializer(typeof(Person[]));
				// десериализираме съдържанието потока в обект
				object o = serializer.Deserialize(stream);

				// десериализаторът връща "object" и трябва да направим
				// явно превръщане към нужния тип
				Person[] p = (Person[])o;

				Console.WriteLine(p);
			}
		}

		private static void DemoXmlReader(string fileName)
		{
			// отваряме файла за четене като поток
			using (var stream = new FileStream(fileName, FileMode.Open, FileAccess.Read))
			// създава четец на XML документи, който да чете от отворения поток
			using (var reader = new XmlTextReader(stream))
			{
				// чете, докато има нещо за четене
				while (reader.Read())
				{
					// разпечатва името на текущата позиция
					Console.WriteLine(reader.Name);
				}
			}
		}

		private static void Main(string[] args)
		{
			// създаваме временен файл
			string fileName = Path.GetTempFileName();

			// демонстрира сериализация
			DemoSerialization(fileName);

			// демонстрира десериализация
			DemoDeserialization(fileName);

			DemoXmlReader(fileName);

			Console.ReadLine();
		}
	}
}
