﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Windows.Forms;
using System.Xml;
using System.Xml.Schema;
using System.Xml.Xsl;

namespace XmlTools
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
		}

		private void btnBrowseXml_Click(object sender, EventArgs e)
		{
			DialogResult dialogResult = ofdXml.ShowDialog();
			if (dialogResult != DialogResult.OK)
				return;

			tbXmlFileName.Text = ofdXml.FileName;
		}

		private void btnAddSchema_Click(object sender, EventArgs e)
		{
			DialogResult dialogResult = ofdSchema.ShowDialog();
			if (dialogResult != DialogResult.OK)
				return;

			foreach (string fileName in ofdSchema.FileNames)
			{
				if (lbSchemaFileNames.Items.Contains(fileName))
					continue;

				lbSchemaFileNames.Items.Add(fileName);
			}
		}

		private void btnRemoveSchemas_Click(object sender, EventArgs e)
		{
			while (lbSchemaFileNames.SelectedItems.Count > 0)
			{
				lbSchemaFileNames.Items.Remove(lbSchemaFileNames.SelectedItems[0]);
			}
		}

		private void btnValidate_Click(object sender, EventArgs e)
		{
			string xmlFileName = tbXmlFileName.Text;

			try
			{
				var errors = new List<string>();

				#region Зареждане на схемите в XmlSchemaSet

				var xmlSchemaSet = new XmlSchemaSet();
				foreach (string fileName in lbSchemaFileNames.Items)
				{
					using (Stream stream = new FileStream(fileName, FileMode.Open, FileAccess.Read))
					{
						XmlSchema xmlSchema = XmlSchema.Read(stream, null);
						xmlSchemaSet.Add(xmlSchema);
					}
				}

				#endregion

				#region Настройки на изчитането на XML документа

				var xmlReaderSettings = new XmlReaderSettings
				{
					ValidationType = ValidationType.Schema,
					ValidationFlags = XmlSchemaValidationFlags.ProcessInlineSchema | XmlSchemaValidationFlags.ReportValidationWarnings,
					Schemas = xmlSchemaSet,
				};
				xmlReaderSettings.ValidationEventHandler += (sender1, e1) =>
				{
					errors.Add(e1.Message);
				};

				#endregion

				#region Изчитане (с валидиране) на XML документа

				using (var stream = new FileStream(xmlFileName, FileMode.Open, FileAccess.Read))
				using (var reader = XmlReader.Create(stream, xmlReaderSettings))
				{
					while (reader.Read()) ;
				}

				#endregion

				if (errors.Count <= 0)
					MessageBox.Show("XML document is valid.", "Success",
						MessageBoxButtons.OK, MessageBoxIcon.Information);
				else
				{
					string errorList = string.Join("\n", errors);
					string message = string.Format("Errors encountered while validating XML document:\n{0})",
						errorList);
					MessageBox.Show(message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void btnBrowseStylesheet_Click(object sender, EventArgs e)
		{
			DialogResult dialogResult = ofdStylesheet.ShowDialog();
			if (dialogResult != DialogResult.OK)
				return;

			tbStylesheetFileName.Text = ofdStylesheet.FileName;
		}

		private void btnTransform_Click(object sender, EventArgs e)
		{
			DialogResult dialogResult = sfdTransformedDocument.ShowDialog();
			if (dialogResult != DialogResult.OK)
				return;

			string xmlFileName = tbXmlFileName.Text;
			string xslFileName = tbStylesheetFileName.Text;
			string transformedFileName = sfdTransformedDocument.FileName;

			try
			{
				#region Създава, зарежда и извършва трансформацията

				var xslTransform = new XslTransform();
				xslTransform.Load(xslFileName);
				xslTransform.Transform(xmlFileName, transformedFileName);

				#endregion

				// отваря резултатния файл по подразбиращия се начин
				Process.Start(transformedFileName);
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}
	}
}
